==> grunt-targethtml-0.1.1.tgz: package/tasks/targethtml.js <==
/*
 * grunt-targethtml
 * https://github.com/changer/grunt-targethtml
 *
 * Copyright (c) 2012 Ruben Stolk
 * Licensed under the MIT license.
 */

module.exports = function(grunt) {

    // Please see the grunt documentation for more information regarding task and
    // helper creation: https://github.com/cowboy/grunt/blob/master/docs/toc.md

    // ==========================================================================
    // TASKS
    // ==========================================================================

    grunt.registerMultiTask('targethtml', 'Produces html-output depending on grunt release version', function() {
        if (!this.data) { return false; }
        grunt.helper('targethtml', this.target, this.data);
    });

    // ==========================================================================
    // HELPERS
    // ==========================================================================

    grunt.registerHelper('targethtml', function(target, data) {
        var file = grunt.file;
        var contents = file.read(data.input);
        if(contents) {
            contents = contents.replace(new RegExp('<!--\\[if target ' + target + '\\]>(<!-->)?([\\s\\S]*?)(<!--)?<!\\[endif\\]-->', 'g'), '$2');
            contents = contents.replace(new RegExp('^[\\s\\t]+<!--\\[if target .*?\\]>(<!-->)?([\\s\\S]*?)(<!--)?<!\\[endif\\]-->[\r\n]*', 'gm'), '');
            contents = contents.replace(new RegExp('<!--\\[if target .*?\\]>(<!-->)?([\\s\\S]*?)(<!--)?<!\\[endif\\]-->[\r\n]*', 'g'), '');
            file.write(data.output, contents);
            console.log('Created ' + data.output, target);
        }
    });

};

==> grunt-targethtml-0.1.2.tgz: package/tasks/targethtml.js <==
/*
 * grunt-targethtml
 * https://github.com/changer/grunt-targethtml
 *
 * Copyright (c) 2012 Ruben Stolk
 * Licensed under the MIT license.
 */

module.exports = function(grunt) {

    // Please see the grunt documentation for more information regarding task and
    // helper creation: https://github.com/cowboy/grunt/blob/master/docs/toc.md

    // ==========================================================================
    // TASKS
    // ==========================================================================

    grunt.registerMultiTask('targethtml', 'Produces html-output depending on grunt release version', function() {
        if (!this.data) { return false; }
        grunt.helper('targethtml', this.target, this.data);
    });

    // ==========================================================================
    // HELPERS
    // ==========================================================================

    grunt.registerHelper('targethtml', function(target, data) {
        var file = grunt.file;
        var contents = file.read(data.input);
        if(contents) {
            contents = contents.replace(new RegExp('<!--[\\[\\(]if target ' + target + '[\\]\\)]>(<!-->)?([\\s\\S]*?)(<!--)?<![\\[\\(]endif[\\]\\)]-->', 'g'), '$2');
            contents = contents.replace(new RegExp('^[\\s\\t]+<!--[\\[\\(]if target .*?[\\]\\)]>(<!-->)?([\\s\\S]*?)(<!--)?<![\\[\\(]endif[\\]\\)]-->[\r\n]*', 'gm'), '');
            contents = contents.replace(new RegExp('<!--[\\[\\(]if target .*?[\\]\\)]>(<!-->)?([\\s\\S]*?)(<!--)?<![\\[\\(]endif[\\]\\)]-->[\r\n]*', 'g'), '');
            file.write(data.output, contents);
            console.log('Created ' + data.output, target);
        }
    });

};
